@@ -15,7 +15,8 @@ def parse_anno(path_anno):
         corresponding data fetched.
         For example:
 
-        {'filename': 'image.jpg',
+        {'annoname': 'xxx.xml',
+         'filename': 'image.jpg',
          'size': {'width': '1621', 'height': '1216', 'depth': '3'},
          'object': [
              {'name': 'class1', 'xmin': '904', 'ymin': '674', 'xmax': '926', 'ymax': '695'},
@@ -58,15 +59,8 @@ def parse_annos(path_anno_folder):
         path_anno: The directory of the annotation files you wanna parse.
 
     Returns:
-        A list of dicts. Each of them mapping filename, size and objects in the annotation to the
-        corresponding data fetched.
-        For example:
-
-        {'filename': 'image.jpg',
-         'size': {'width': '1621', 'height': '1216', 'depth': '3'},
-         'object': [
-             {'name': 'class1', 'xmin': '904', 'ymin': '674', 'xmax': '926', 'ymax': '695'},
-             {'name': 'class2', 'xmin': '972', 'ymin': '693', 'xmax': '993', 'ymax': '713'}]}
+        A dict of dicts. Each of them mapping annotation file name("annoname")
+        to the corresponding annotation dict fetched by parse_anno().
     """
     path_annos = [os.path.join(path_anno_folder, i)
                   for i in os.listdir(path_anno_folder)]
@@ -74,7 +68,10 @@ def parse_annos(path_anno_folder):
     res = pool.map(parse_anno, path_annos)
     pool.close()
     pool.join()
-    return res
+    annos_dict = {}
+    for anno in res:
+        annos_dict[anno['annoname']] = anno
+    return annos_dict
 
 
 def check_match(path_1, path_2):
@@ -166,7 +163,7 @@ def gen_labels(path_anno_folder, path_names, path_out):
     pool.join()
 
 
-def distribution(path_anno_folder, verbose=0):
+def bbox_distribution(path_anno_folder, verbose=0):
     """
     Analysis the bbox distribution by a list of annotation files.
 
